@@ -124,7 +124,7 @@ class Namespace(SessionBound):
         self.api.post(name, description)
         return Namespace(path_child(self.path, name))
 
-    def create_tag(self, name, description, indexed):
+    def create_tag(self, name, description, indexed=False):
         """Create a tag in this namespace, and return it.
 
         :param name: The name of the Tag to be created
@@ -349,16 +349,17 @@ class Object(SessionBound):
         self._path_map = {}
         for attribute, tag in _get_tag_values(self.__class__):
             self._path_map[tag.tagpath] = attribute
-        # check about isn't in the initial values
-        if 'fluiddb/about' in initial:
-            if about is None:
-                about = initial['fluiddb/about']['value']
-                del initial['fluiddb/about']
-        # react appropriately to an about value
-        if about is not None:
-            self.create(about)
         # cache for tag values
         self._cache = {}
+        # check about isn't in the initial values
+        if uid and 'fluiddb/about' in initial:
+            if about is None:
+                self.about = initial['fluiddb/about']['value']
+                self._cache['fluiddb/about'] = self.about
+                del initial['fluiddb/about']
+        # react appropriately to an about value
+        elif about is not None:
+            self.create(about)
         # a list of fields whose value has been updated but not saved
         self._dirty_fields = set()
         # if there are some initial values then set them for the appropriate
@@ -376,6 +377,7 @@ class Object(SessionBound):
         r = self.fluid.objects.post(about)
         self.uid = r.value[u'id']
         self.about = about
+        self._cache['fluiddb/about'] = self.about
 
     def get(self, tagpath):
         """Get the value of a tag.
@@ -503,9 +505,18 @@ class Object(SessionBound):
         If result_type is passed the results will be instantiated as a list of
         result_type otherwise they'll be instantiations of cls.
         """
-        objects = Fluid.bound.objects.get(query)
         class_type = result_type and result_type or cls
-        return [class_type(uid) for uid in objects.value['ids']]
+        if class_type == Object:
+            objects = Fluid.bound.objects.get(query)
+            return [class_type(uid) for uid in objects.value['ids']]
+        else:
+            tag_list = ['fluiddb/about', ]
+            tag_list.extend([attribute.tagpath for attribute in
+                class_type.__dict__.values()
+                if isinstance(attribute, readonly_tag_value)])
+            objects = Fluid.bound.values.get(query, tag_list)
+            return [class_type(uid, initial=values) for uid, values in
+                objects.value['results']['id'].iteritems()]
 
     def __repr__(self):
         return '<%s %s>' % (self.__class__.__name__, self.uid)
